package com.example.sam4s;

import com.example.sam4s.R;
import com.sam4s.printer.Sam4sBuilder;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.KeyEvent;
import android.view.View; 
import android.view.WindowManager.LayoutParams;
import android.widget.AdapterView;
import android.widget.AdapterView.OnItemSelectedListener;
import android.widget.ArrayAdapter;
import android.widget.Button;
import android.widget.Spinner;
import android.widget.TextView;

public class cl_Barcode2D extends Activity {

    static final int SEND_TIMEOUT = 10 * 1000;
    
    static final int SYMBOL_PDF417_STANDARD_INDEX = 0;
    static final int SYMBOL_PDF417_TRUNCATED_INDEX = 1;
    static final int SYMBOL_QRCODE_MODEL_1_INDEX = 2;
    static final int SYMBOL_QRCODE_MODEL_2_INDEX = 3;
    
    boolean changeBarcodeData = false;
    String defaultBarcodeData = "";
    boolean exitActivity = false;

    @Override
    public void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.code2d);
    
        //check close port
        if(cl_Menu.mPrinter == null){
            finish();
            return ;
        }
        
        //init type list
        Spinner spinner = (Spinner)findViewById(R.id.spinner_type);
        ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        int[] typelist = {
                R.string.code2type_pdf417s,
                R.string.code2type_qr1
        };
        for(int i = 0; i < typelist.length; i++){
            adapter.add(getString(typelist[i]));
        }
        spinner.setAdapter(adapter);
        
        //init level list
        setLevelList();

        //default setting
        setDefaultSetting();
        setDefaultBarcodeData();
        
        //Registration ClickListener
        Button button = (Button)findViewById(R.id.button_print);
        button.setOnClickListener(new BtnPrintClick());
        
        //register OnCheckedChangeListener
        spinner = (Spinner)findViewById(R.id.spinner_type);
        spinner.setOnItemSelectedListener(new SpinerOnItemSelected());

        //hide keyboard
        this.getWindow().setSoftInputMode(LayoutParams.SOFT_INPUT_STATE_ALWAYS_HIDDEN);
    }
    
    @Override
    public boolean onKeyDown(int keyCode, KeyEvent event) {
        if(keyCode == KeyEvent.KEYCODE_BACK){
            exitActivity = true;
        }
        
        return super.onKeyDown(keyCode, event);
    }
    
    class BtnPrintClick implements View.OnClickListener {
		@Override
		public void onClick(View v) {
	        printBarcode();
		}
    }
    
    class SpinerOnItemSelected implements OnItemSelectedListener {
		@Override
		public void onItemSelected(AdapterView<?> arg0, View arg1, int arg2,
				long arg3) {
			//reset level list
	        setLevelList();

	        //set default settings
	        setDefaultSetting();

	        //check default change
	        TextView text = (TextView)findViewById(R.id.editText_data);
	        if(defaultBarcodeData.compareTo(text.getText().toString()) != 0){
	            changeBarcodeData = true;
	        }
	        if(changeBarcodeData){
	            //not update
	            return;
	        }
	        
	        //update barcode data
	        setDefaultBarcodeData();			
		}

		@Override
		public void onNothingSelected(AdapterView<?> arg0) {
			return ;			
		}
    }

    private void printBarcode(){
        TextView text = (TextView)findViewById(R.id.editText_data);
        if(text.getText().toString().isEmpty()){
        	cl_Main.showMsg("No Data Error", cl_Barcode2D.this);
            return ;
        }

        Sam4sBuilder builder = null;     
        try{
            //create builder
            Intent intent = getIntent();
            //Builder
            builder = new Sam4sBuilder(
                    intent.getStringExtra("printername"), intent.getIntExtra("language", 0));

            //add command
            //addSymbol
            builder.addSymbol(
                    getBuilderData(),
                    getBuilderType(),
                    getBuilderLevel(),
                    getBuilderWidth(),
                    getBuilderHeight(),
                    getBuilderMaxSize());

            //send builder data
            try{
            	cl_Menu.mPrinter.sendData(builder);                
            }catch(Exception e){
            	cl_Main.showMsg(e.getLocalizedMessage(), cl_Barcode2D.this);
            }
        }catch(Exception e){
        	cl_Main.showMsg(e.getLocalizedMessage(), cl_Barcode2D.this);
        }
        
        //remove builder
        if(builder != null){
            try{
                builder.clearCommandBuffer();
                builder = null;
            }catch(Exception e){
                builder = null;
            }
        }
    }
    
    private String getBuilderData(){
        TextView text = (TextView)findViewById(R.id.editText_data);
        return text.getText().toString();
    }
    
    private int getBuilderType(){
        Spinner spinner = (Spinner)findViewById(R.id.spinner_type);
        int[] typelist = {
                Sam4sBuilder.SYMBOL_PDF417_STANDARD,
                Sam4sBuilder.SYMBOL_QRCODE_MODEL
        };
        if(spinner.getSelectedItemPosition() < typelist.length){
            return typelist[spinner.getSelectedItemPosition()];
        }else{
            return typelist[0];
        }
    }

    private int getBuilderLevel(){
        Spinner spinner = (Spinner)findViewById(R.id.spinner_type);
        int[] levellist = null;
        int[] pdf417levellist = {
        		Sam4sBuilder.LEVEL_0,
        		Sam4sBuilder.LEVEL_1,
        		Sam4sBuilder.LEVEL_2,
        		Sam4sBuilder.LEVEL_3,
        		Sam4sBuilder.LEVEL_4,
        		Sam4sBuilder.LEVEL_5,
        		Sam4sBuilder.LEVEL_6,
                Sam4sBuilder.LEVEL_7,
                Sam4sBuilder.LEVEL_8,
        };
        int[] qrlevellist = {
        		Sam4sBuilder.LEVEL_L,
        		Sam4sBuilder.LEVEL_M,
        		Sam4sBuilder.LEVEL_Q,
        		Sam4sBuilder.LEVEL_H,
        };
        switch(spinner.getSelectedItemPosition()){
        case SYMBOL_PDF417_STANDARD_INDEX:
        case SYMBOL_PDF417_TRUNCATED_INDEX:
            levellist = pdf417levellist;
            break;
        case SYMBOL_QRCODE_MODEL_1_INDEX:
        case SYMBOL_QRCODE_MODEL_2_INDEX:
            levellist = qrlevellist;
            break;
        default:
            break;
        }
        if(levellist == null){
            return Sam4sBuilder.LEVEL_DEFAULT;
        }else{
           spinner = (Spinner)findViewById(R.id.spinner_level);
           if(spinner.getSelectedItemPosition() < levellist.length){
               return levellist[spinner.getSelectedItemPosition()];
           }else{
               return levellist[0];
           }
        }
    }

    private int getBuilderWidth(){
        TextView text = (TextView)findViewById(R.id.editText_modulesize_w);
        if(text.isEnabled()){
            try{
                return Integer.parseInt(text.getText().toString());
            }catch(Exception e){
                return 0;
            }
        }else{
            return Sam4sBuilder.PARAM_UNSPECIFIED;
        }
    }

    private int getBuilderHeight(){
        TextView text = (TextView)findViewById(R.id.editText_modulesize_h);
        if(text.isEnabled()){
            try{
                return Integer.parseInt(text.getText().toString());
            }catch(Exception e){
                return 0;
            }
        }else{
            return Sam4sBuilder.PARAM_UNSPECIFIED;
        }
    }
    
    private int getBuilderMaxSize(){
        TextView text = (TextView)findViewById(R.id.editText_maxsize);
        if(text.isEnabled()){
            try{
                return Integer.parseInt(text.getText().toString());
            }catch(Exception e){
                return 0;
            }
        }else{
            return Sam4sBuilder.PARAM_UNSPECIFIED;
        }
    }
    
    private void setLevelList(){
        Spinner spinner = (Spinner)findViewById(R.id.spinner_type);
        int[] levellist = null;
        int[] pdf417levellist = {
                R.string.level_pdf417_0,
                R.string.level_pdf417_1,
                R.string.level_pdf417_2,
                R.string.level_pdf417_3,
                R.string.level_pdf417_4,
                R.string.level_pdf417_5,
                R.string.level_pdf417_6,
                R.string.level_pdf417_7,
                R.string.level_pdf417_8,
        };
        int[] qrlevellist = {
                R.string.level_qr_l,
                R.string.level_qr_m,
                R.string.level_qr_q,
                R.string.level_qr_h,
        };
        switch(spinner.getSelectedItemPosition()){
        case SYMBOL_PDF417_STANDARD_INDEX:
        case SYMBOL_PDF417_TRUNCATED_INDEX:
            levellist = pdf417levellist;
            break;
        case SYMBOL_QRCODE_MODEL_1_INDEX:
        case SYMBOL_QRCODE_MODEL_2_INDEX:
            levellist = qrlevellist;
            break;
        default:
             break;
        }
        
        spinner = (Spinner)findViewById(R.id.spinner_level);
        if(levellist == null){
            //disable
            ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item);
            adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
            spinner.setAdapter(adapter);
            adapter.add(getString(R.string.empty));
            spinner.setEnabled(false);
        }else{
            ArrayAdapter<String> adapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item);
            adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
            for(int i = 0; i < levellist.length; i++){
                adapter.add(getString(levellist[i]));
            }
            spinner.setAdapter(adapter);
            spinner.setEnabled(true);
        }
    }
    
    private void setDefaultSetting(){
        Spinner spinner = (Spinner)findViewById(R.id.spinner_type);

        TextView textModuleW = (TextView)findViewById(R.id.editText_modulesize_w);
        TextView textModuleH = (TextView)findViewById(R.id.editText_modulesize_h);
        TextView textModuleMaxsize = (TextView)findViewById(R.id.editText_maxsize);
        switch(spinner.getSelectedItemPosition()){
        case SYMBOL_PDF417_STANDARD_INDEX:
        case SYMBOL_PDF417_TRUNCATED_INDEX:
            textModuleW.setText("3");
            textModuleH.setText("3");
            textModuleMaxsize.setText("0");
            textModuleW.setEnabled(true);
            textModuleH.setEnabled(true);
            textModuleMaxsize.setEnabled(true);
            break;
        case SYMBOL_QRCODE_MODEL_1_INDEX:
        case SYMBOL_QRCODE_MODEL_2_INDEX:
            textModuleW.setText("3");
            textModuleH.setText("");
            textModuleMaxsize.setText("");
            textModuleW.setEnabled(true);
            textModuleH.setEnabled(false);
            textModuleMaxsize.setEnabled(false);
            break;
        default:
            break;
        }
    }
    
    private void setDefaultBarcodeData(){
        //update default data
        defaultBarcodeData = getDefaultBarcodeData();

        //update ui
        TextView text = (TextView)findViewById(R.id.editText_data);
        text.setText(defaultBarcodeData);
    }
    
    private String getDefaultBarcodeData(){
        Spinner spinner = (Spinner)findViewById(R.id.spinner_type);
        int defaultDataNo = 0;
        int[] dataList = {
                R.string.code2data_pdf417s,
                R.string.code2data_pdf417t,
                R.string.code2data_qr1,
                R.string.code2data_qr2,
                R.string.code2data_maxcode2,
                R.string.code2data_maxcode3,
                R.string.code2data_maxcode4,
                R.string.code2data_maxcode5,
                R.string.code2data_maxcode6,
                R.string.code2data_gr1st,
                R.string.code2data_gr1so,
                R.string.code2data_gr1es,
        };
        if(spinner.getSelectedItemPosition() < dataList.length){
            defaultDataNo = dataList[spinner.getSelectedItemPosition()];
        }else{
            defaultDataNo = dataList[0];
        }
        
        return getString(defaultDataNo);
    }
}
