package com.example.sam4s;

import com.example.sam4s.R;
import com.sam4s.printer.Sam4sPrint;
import com.sam4s.io.serial.sap4k.*;

import android.app.Activity;
import android.content.Intent;
import android.os.Bundle;
import android.view.View;
import android.widget.ArrayAdapter;
import android.widget.EditText;
import android.widget.LinearLayout;
import android.widget.RadioGroup;
import android.widget.Button;
import android.widget.Spinner;

public class cl_Manual extends Activity 
{	
	private RadioGroup rgDeviceType;
	
	private int mSearchType = 0;

	private Button btnConnect;
	private LinearLayout lilEthernet;
	private LinearLayout lilSerial;
	
	private EditText txtIpAddress;
	
	private Spinner spin_PortNo;
	private Spinner spin_Baudrate;
	private Spinner spin_Databit;
	private Spinner spin_Stopbit;
	
	private ArrayAdapter<String> adapter;
	
	
	@Override  
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.manual);

		rgDeviceType = (RadioGroup)findViewById(R.id.radioGroup1);
		rgDeviceType.setOnCheckedChangeListener(mRadioCheck);     		
		
		lilEthernet = (LinearLayout)findViewById(R.id.linearLayout_Ethernet);
		lilSerial = (LinearLayout)findViewById(R.id.linearLayout_Serial);
		
		txtIpAddress = (EditText)findViewById(R.id.txtIpAddress);
		
		btnConnect = (Button)findViewById(R.id.btnConnect);
		btnConnect.setOnClickListener(new btnConnectOnClick());		
		
		//init type list
		spin_PortNo = (Spinner)findViewById(R.id.spin_PortNo);
        adapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);    
        SerialControl.SERIAL_NO[] serialList = SerialControl.SERIAL_NO.values();
        for(int i=0; i < serialList.length; i++)
        {
        	adapter.add(serialList[i].toString());
        }               
        spin_PortNo.setAdapter(adapter);
        spin_PortNo.setSelection(0);
        
        spin_Baudrate = (Spinner)findViewById(R.id.spin_Baudrate);
        adapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        SerialControl.BAUD[] baudrateList = SerialControl.BAUD.values();
        for(int i=0; i < baudrateList.length; i++)
        {
        	adapter.add(baudrateList[i].toString());
        }               
        spin_Baudrate.setAdapter(adapter);
        spin_Baudrate.setSelection(7);		
        
        spin_Databit = (Spinner)findViewById(R.id.spin_Databit);
        adapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        SerialControl.DATABITS[] databitList = SerialControl.DATABITS.values();
        for(int i=0; i < databitList.length; i++)
        {
        	adapter.add(databitList[i].toString());
        }   
        spin_Databit.setAdapter(adapter);
        spin_Databit.setSelection(4);		
       
        spin_Stopbit = (Spinner)findViewById(R.id.spin_Stopbit);
        adapter = new ArrayAdapter<String>(this, android.R.layout.simple_spinner_item);
        adapter.setDropDownViewResource(android.R.layout.simple_spinner_dropdown_item);
        SerialControl.STOPBITS[] stopbitList = SerialControl.STOPBITS.values();
        for(int i=0; i < stopbitList.length; i++)
        {
        	adapter.add(stopbitList[i].toString());
        }   
        spin_Stopbit.setAdapter(adapter);
        spin_Stopbit.setSelection(0);
	}
	
	class btnConnectOnClick implements View.OnClickListener
	{
		public void onClick(View v)
		{
			try
			{	
				cl_Menu.mPrinter.closePrinter();
				boolean ret = false;
				
				switch(mSearchType)
				{
					case 0:
						if(txtIpAddress.getText().toString().isEmpty())
						{
							cl_Main.showMsg("Please fill the IP address", cl_Manual.this);
							return;
						}
						
						ret = cl_Menu.mPrinter.openPrinter(Sam4sPrint.DEVTYPE_ETHERNET, txtIpAddress.getText().toString());						
						break;
					case 1:
						ret = cl_Menu.mPrinter.openPrinter(Sam4sPrint.DEVTYPE_SERIAL_SAP4K, 
								SerialControl.SERIAL_NO.valueOf(spin_PortNo.getSelectedItem().toString()),
								SerialControl.BAUD.valueOf(spin_Baudrate.getSelectedItem().toString()),
								SerialControl.DATABITS.valueOf(spin_Databit.getSelectedItem().toString()),
								SerialControl.STOPBITS.valueOf(spin_Stopbit.getSelectedItem().toString()),
								SerialControl.FLOW_CONTROL.XON_XOFF,
								SerialControl.PARITY_CHECK.NONE
								);						
						break;
				}
									
				if(ret == false)
				{
					cl_Main.showMsg("Fail to Open Printer", cl_Manual.this);
					return;
				}	
				
				Intent MenuIntent = new Intent(getBaseContext(), cl_Menu.class);
				startActivityForResult(MenuIntent, cl_Main.ACTIVITY_MENU);     								
			}
			catch(Exception ex)
			{
				ex.printStackTrace();				
			}
		}
	}
	
	RadioGroup.OnCheckedChangeListener mRadioCheck = new RadioGroup.OnCheckedChangeListener() 
	{
		@Override
		public void onCheckedChanged(RadioGroup group, int checkedId) 
		{
			if(group.getId() == R.id.radioGroup1)
			{				
				switch(checkedId)
				{
					// Ethernet
					case R.id.radio1:
						mSearchType = 0;	
						lilEthernet.setVisibility(View.VISIBLE);
						lilSerial.setVisibility(View.GONE);
						break;
					// Serial
					case R.id.radio2:
						mSearchType = 1;
						lilEthernet.setVisibility(View.GONE);
						lilSerial.setVisibility(View.VISIBLE);
						break;
				}
			}
		}
	};	
}
